==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/zh_CN.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "正在加载预览...",
    "Saved" : "已保存",
    "Admin" : "管理",
    "a safe home for all your data" : "给您所有的数据一个安全的家",
    "Name cannot be empty" : "名称不能为空",
    "The given name is too long" : "输入的名称过长",
    "The given web address is too long" : "输入的地址过长",
    "The given web address is not a valid URL" : "提供的web地址不是一个合法的URL",
    "The given legal notice address is too long" : "提供的法律通告地址太长",
    "The given legal notice address is not a valid URL" : "提供的法律通告地址不是一个合法的URL",
    "The given privacy policy address is too long" : "提供的隐私政策地址太长",
    "The given privacy policy address is not a valid URL" : "提供的隐私政策地址不是一个合法的URL",
    "The given slogan is too long" : "输入的标语过长",
    "The given color is invalid" : "提供的颜色无效",
    "The file was uploaded" : "文件已上传",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传的文件超出了 php.ini 中的 upload_max_filesize 的值",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件超过了 HTML 表单中指定的 MAX_FILE_SIZE 指令",
    "The file was only partially uploaded" : "该文件只有部分被上传",
    "No file was uploaded" : "没有文件被上传",
    "Missing a temporary folder" : "缺少临时文件夹",
    "Could not write file to disk" : "无法写入文件到磁盘",
    "A PHP extension stopped the file upload" : "PHP 扩展停止了文件上传。",
    "No file uploaded" : "文件没有上传",
    "Unsupported image type" : "不支持图片格式",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "你已经在使用一个自定义的主题。主题应用的设置可能会被其覆盖。",
    "Theming" : "主题",
    "Legal notice" : "法律声明",
    "Privacy policy" : "隐私政策",
    "Adjust the Nextcloud theme" : "调整 Nextcloud 主题",
    "Open documentation" : "打开文档",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "主题使得方便地定制您的实例的外观和体验成为可能。所有用户都可以使用。",
    "Name" : "名字",
    "Reset to default" : "重置为默认设置",
    "Web link" : "网站链接",
    "https://…" : "https://",
    "Slogan" : "标语",
    "Color" : "颜色",
    "Logo" : "图标",
    "Upload new logo" : "上传新的图标",
    "Login image" : "登录图片",
    "Upload new login background" : "上传新登录背景",
    "Remove background image" : "删除背景图片",
    "Advanced options" : "高级选项",
    "Legal notice link" : "法律声明链接",
    "Privacy policy link" : "隐私政策链接",
    "Header logo" : "顶栏图标",
    "Upload new header logo" : "上传新的顶栏图标",
    "Favicon" : "网站图标",
    "Upload new favicon" : "上传新图标",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "安装支持 SVG 图像的 PHP 扩展 Imagemagick，以根据上传的 logo 和颜色自动生成图标。"
},
"nplurals=1; plural=0;");

==> nextcloud-18.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/zh_CN.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "正在加载预览...",
    "Saved" : "已保存",
    "Admin" : "管理",
    "a safe home for all your data" : "给您所有的数据一个安全的家",
    "Name cannot be empty" : "名称不能为空",
    "The given name is too long" : "输入的名称过长",
    "The given web address is too long" : "输入的地址过长",
    "The given web address is not a valid URL" : "提供的web地址不是一个合法的URL",
    "The given legal notice address is too long" : "提供的法律通告地址太长",
    "The given legal notice address is not a valid URL" : "提供的法律通告地址不是一个合法的URL",
    "The given privacy policy address is too long" : "提供的隐私政策地址太长",
    "The given privacy policy address is not a valid URL" : "提供的隐私政策地址不是一个合法的URL",
    "The given slogan is too long" : "输入的标语过长",
    "The given color is invalid" : "提供的颜色无效",
    "The file was uploaded" : "文件已上传",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传的文件超出了 php.ini 中的 upload_max_filesize 的值",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件超过了 HTML 表单中指定的 MAX_FILE_SIZE 指令",
    "The file was only partially uploaded" : "该文件只有部分被上传",
    "No file was uploaded" : "没有文件被上传",
    "Missing a temporary folder" : "缺少临时文件夹",
    "Could not write file to disk" : "无法写入文件到磁盘",
    "A PHP extension stopped the file upload" : "PHP 扩展停止了文件上传。",
    "No file uploaded" : "文件没有上传",
    "Unsupported image type" : "不支持图片格式",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "你已经在使用一个自定义的主题。主题应用的设置可能会被其覆盖。",
    "Theming" : "主题",
    "Legal notice" : "法律声明",
    "Privacy policy" : "隐私政策",
    "Adjust the Nextcloud theme" : "调整 Nextcloud 主题",
    "Open documentation" : "打开文档",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "主题使得方便地定制您的实例的外观和体验成为可能。所有用户都可以使用。",
    "Name" : "名字",
    "Reset to default" : "重置为默认设置",
    "Web link" : "网站链接",
    "https://…" : "https://…",
    "Slogan" : "标语",
    "Color" : "颜色",
    "Logo" : "图标",
    "Upload new logo" : "上传新的图标",
    "Login image" : "登录图片",
    "Upload new login background" : "上传新登录背景",
    "Remove background image" : "删除背景图片",
    "Advanced options" : "高级选项",
    "Legal notice link" : "法律声明链接",
    "Privacy policy link" : "隐私政策链接",
    "Header logo" : "顶栏图标",
    "Upload new header logo" : "上传新的顶栏图标",
    "Favicon" : "网站图标",
    "Upload new favicon" : "上传新图标",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "安装支持 SVG 图像的 PHP 扩展 Imagemagick，以根据上传的 logo 和颜色自动生成图标。"
},
"nplurals=1; plural=0;");
